@@ -446,7 +446,7 @@ class DeepNetwork():
 			x=BatchNormalization()(x)
 			x=Dropout(0.5)(x)
 			if classes==2:
-				x=Dense(1,activation='softmax')(x)
+				x=Dense(1,activation='sigmoid')(x)
 			else:
 				x=Dense(classes,activation='softmax')(x)
 
@@ -500,7 +500,7 @@ class DeepNetwork():
 			x=BatchNormalization()(x)
 			x=Dropout(0.5)(x)
 			if classes==2:
-				x=Dense(1,activation='softmax')(x)
+				x=Dense(1,activation='sigmoid')(x)
 			else:
 				x=Dense(classes,activation='softmax')(x)
 
@@ -651,7 +651,7 @@ class DeepNetwork():
 
 			x=Dropout(0.5)(x)
 			if classes==2:
-				x=Dense(1,activation='softmax')(x)
+				x=Dense(1,activation='sigmoid')(x)
 			else:
 				x=Dense(classes,activation='softmax')(x)
 
@@ -720,7 +720,7 @@ class DeepNetwork():
 				
 			x=Dropout(0.5)(x)
 			if classes==2:
-				x=Dense(1,activation='softmax')(x)
+				x=Dense(1,activation='sigmoid')(x)
 			else:
 				x=Dense(classes,activation='softmax')(x)
 
@@ -775,7 +775,7 @@ class DeepNetwork():
 		outputs=BatchNormalization()(outputs)
 		outputs=Dropout(0.5)(outputs)
 		if classes==2:
-			predictions=Dense(1,activation='softmax')(outputs)
+			predictions=Dense(1,activation='sigmoid')(outputs)
 		else:
 			predictions=Dense(classes,activation='softmax')(outputs)
 
